Welcome to teslajsonpy’s documentation! — teslajsonpy 0.12.2 documentation

# Welcome to teslajsonpy’s documentation!

# teslajsonpy

Async python module for Tesla API primarily for enabling Home-Assistant.

NOTE: Tesla has no official API; therefore, this library may stop working at any time without warning.

# Credits

Originally inspired by this code. Also thanks to Tim Dorr for documenting the API. Additional repo scaffolding from simplisafe-python.

# Contributing

1. Check for open features/bugs or initiate a discussion on one.

2. Fork the repository.

3. Install the dev environment: `make init`.

4. Enter the virtual environment: `pipenv shell`

5. Code your new feature or bug fix. Developers Reference

6. Write a test that covers your new functionality.

7. Update `README.md` with any new documentation.

8. Run tests and ensure 100% code coverage for your contribution: `make coverage`

9. Ensure you have no linting errors: `make lint`

10. Ensure you have typed your code correctly: `make typing`

11. Add yourself to `AUTHORS.md`.

12. Submit a pull request!

# License

Apache-2.0. By providing a contribution, you agree the contribution is licensed under Apache-2.0. This code is provided as-is with no warranty. Use at your own risk.

# API Reference

- `teslajsonpy`
  - Submodules
    - `teslajsonpy.__version__`
    - `teslajsonpy.connection`
    - `teslajsonpy.const`
    - `teslajsonpy.controller`
    - `teslajsonpy.exceptions`
    - `teslajsonpy.homeassistant`
    - `teslajsonpy.teslaproxy`
  - Classes
  - Exceptions
  - Variables

# Indices and tables

- Index

- Module Index

- Search Page